@@ -1,10 +1,9 @@
 #' ggbeeswarm extends ggplot2 with violin point/beeswarm plots
 #' 
 #' This package allows plotting of several groups of one dimensional data as a violin point/beeswarm plot in ggplot2 by arranging data points to resemble the underlying distribution. The development version of this package is on <https://github.com/eclarke/ggbeeswarm>.
-#' @docType package
 #' @name ggbeeswarm
 #' @author Erik Clarke, \email{erikclarke@@gmail.com}
-#' @seealso [position_quasirandom()]
+#' @seealso [position_quasirandom()], [position_beeswarm()]
 #' @examples
 #' 
 #'   ggplot2::ggplot(ggplot2::mpg,aes(class, hwy)) + geom_quasirandom()
@@ -16,5 +15,5 @@
 #'   ggplot2::ggplot(distro,aes(variable, value)) + geom_quasirandom()
 #'   ggplot2::ggplot(distro,aes(variable, value)) + geom_quasirandom(width=.1)
 #' 
-NULL
+"_PACKAGE"
 
